@@ -6,9 +6,13 @@ from os.path import dirname
 rootDir = dirname(__file__)
 
 sys.path.append(rootDir)
-os.environ["PATH"] = os.environ["PATH"] + os.pathsep + os.path.join(rootDir, "dlls")
-
-#dataFileList = glob(os.path.join(rootDir, "datas", "*.*"))
+os.environ["PATH"] = os.environ["PATH"] + os.path.join(rootDir, "dlls") + os.pathsep
+os.environ["DLL_FOLDER"] = os.path.join(rootDir, "dlls")
 os.environ["DNN_DATA_FOLDER"] = os.path.join(rootDir, "models")
 os.environ["IMG_DATA_FOLDER"] = os.path.join(rootDir, "imgs")
-#os.environ["PATH"] = os.environ["PATH"] + os.pathsep + os.path.join(rootDir, "datas")
\ No newline at end of file
+
+
+import dd
+import image
+import record
+import memory
\ No newline at end of file
